@@ -88,7 +88,7 @@ void SPVM_CSOURCE_BUILDER_EXE_add_set_sub_native_addresses(SPVM_ENV* env, SPVM_P
       const char* sub_name = &runtime->string_pool[sub->name_id];
       const char* sub_package_name = &runtime->string_pool[sub_package->name_id];
       
-      SPVM_STRING_BUFFER_add(string_buffer, "  runtime->sub_native_addresses[");
+      SPVM_STRING_BUFFER_add(string_buffer, "  runtime->sub_cfunc_addresses[");
       SPVM_STRING_BUFFER_add_int(string_buffer, sub->id);
       SPVM_STRING_BUFFER_add(string_buffer, "] = SPVM_NATIVE_");
       SPVM_STRING_BUFFER_add_package_name(string_buffer, sub_package_name);
@@ -110,7 +110,7 @@ void SPVM_CSOURCE_BUILDER_EXE_add_set_sub_precompile_addresses(SPVM_ENV* env, SP
       const char* sub_name = &runtime->string_pool[sub->name_id];
       const char* sub_package_name = &runtime->string_pool[sub_package->name_id];
       
-      SPVM_STRING_BUFFER_add(string_buffer, "  runtime->sub_precompile_addresses[");
+      SPVM_STRING_BUFFER_add(string_buffer, "  runtime->sub_cfunc_addresses[");
       SPVM_STRING_BUFFER_add_int(string_buffer, sub->id);
       SPVM_STRING_BUFFER_add(string_buffer, "] = SPVM_PRECOMPILE_");
       SPVM_STRING_BUFFER_add_package_name(string_buffer, sub_package_name);
@@ -302,6 +302,21 @@ void SPVM_CSOURCE_BUILDER_EXE_build_exe_csource(SPVM_ENV* env, SPVM_STRING_BUFFE
     SPVM_STRING_BUFFER_add(string_buffer, ".no_dup_basic_type_ids_constant_pool_id = ");
     SPVM_STRING_BUFFER_add_int(string_buffer, runtime_package->no_dup_package_var_access_package_var_ids_constant_pool_id);
     SPVM_STRING_BUFFER_add(string_buffer, ", ");
+    SPVM_STRING_BUFFER_add(string_buffer, ".subs_base = ");
+    SPVM_STRING_BUFFER_add_int(string_buffer, runtime_package->subs_base);
+    SPVM_STRING_BUFFER_add(string_buffer, ", ");
+    SPVM_STRING_BUFFER_add(string_buffer, ".subs_length = ");
+    SPVM_STRING_BUFFER_add_int(string_buffer, runtime_package->subs_length);
+    SPVM_STRING_BUFFER_add(string_buffer, ", ");
+    SPVM_STRING_BUFFER_add(string_buffer, ".package_vars_base = ");
+    SPVM_STRING_BUFFER_add_int(string_buffer, runtime_package->package_vars_base);
+    SPVM_STRING_BUFFER_add(string_buffer, ", ");
+    SPVM_STRING_BUFFER_add(string_buffer, ".package_vars_length = ");
+    SPVM_STRING_BUFFER_add_int(string_buffer, runtime_package->package_vars_length);
+    SPVM_STRING_BUFFER_add(string_buffer, ", ");
+    SPVM_STRING_BUFFER_add(string_buffer, ".object_field_indexes_constant_pool_id = ");
+    SPVM_STRING_BUFFER_add_int(string_buffer, runtime_package->object_field_indexes_constant_pool_id);
+    SPVM_STRING_BUFFER_add(string_buffer, ", ");
     SPVM_STRING_BUFFER_add(string_buffer, "}");
 
     SPVM_STRING_BUFFER_add(string_buffer, ",\n");
